@@ -73,12 +73,12 @@ pub fn sanit_filter<S: BuildHasher>(
         None => false,
     };
 
-    let mut filtered = sanitize(&pstr);
+    let mut filtered = sanitize(pstr);
 
-    if alpha_required {
-        if filtered.starts_with(&CFG.filename.sort_tag_chars.chars().collect::<Vec<char>>()[..]) {
-            filtered.insert(0, CFG.filename.sort_tag_extra_separator);
-        };
+    if alpha_required
+        && filtered.starts_with(&CFG.filename.sort_tag_chars.chars().collect::<Vec<char>>()[..])
+    {
+        filtered.insert(0, CFG.filename.sort_tag_extra_separator);
     };
 
     Ok(to_value(&filtered)?)
